package cn.com.infosec.crypto.params;

import cn.com.infosec.crypto.CipherParameters;
import java.math.BigInteger;

public class GOST3410Parameters implements CipherParameters {
   private BigInteger p;
   private BigInteger q;
   private BigInteger a;
   private GOST3410ValidationParameters validation;

   public GOST3410Parameters(BigInteger p, BigInteger q, BigInteger a) {
      this.p = p;
      this.q = q;
      this.a = a;
   }

   public GOST3410Parameters(BigInteger p, BigInteger q, BigInteger a, GOST3410ValidationParameters params) {
      this.a = a;
      this.p = p;
      this.q = q;
      this.validation = params;
   }

   public BigInteger getP() {
      return this.p;
   }

   public BigInteger getQ() {
      return this.q;
   }

   public BigInteger getA() {
      return this.a;
   }

   public GOST3410ValidationParameters getValidationParameters() {
      return this.validation;
   }

   public int hashCode() {
      return this.p.hashCode() ^ this.q.hashCode() ^ this.a.hashCode();
   }

   public boolean equals(Object obj) {
      if (!(obj instanceof GOST3410Parameters)) {
         return false;
      } else {
         GOST3410Parameters obj1;
         return (obj1 = (GOST3410Parameters)obj).getP().equals(this.p) && obj1.getQ().equals(this.q) && obj1.getA().equals(this.a);
      }
   }
}
